==> apache-cxf-3.1.15-src.zip: apache-cxf-3.1.15-src/rt/frontend/jaxrs/src/test/java/org/apache/cxf/jaxrs/provider/RequestDispatcherProviderTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.jaxrs.provider;

import java.util.Collections;

import org.junit.Assert;
import org.junit.Test;

public class RequestDispatcherProviderTest extends Assert {
    
    @Test
    public void testIsWriteableEnum() {
        
        RequestDispatcherProvider p = new RequestDispatcherProvider();
        p.setClassResources(
            Collections.singletonMap(TestEnum.class.getName() + "." + TestEnum.ONE, "/test.jsp"));
        assertTrue(p.isWriteable(TestEnum.ONE.getClass(), null, null, null));
        assertEquals("/test.jsp", p.getResourcePath(TestEnum.ONE.getClass(), TestEnum.ONE));
    }
    
    @Test
    public void testIsWriteableEnum2() {
        
        RequestDispatcherProvider p = new RequestDispatcherProvider();
        p.setEnumResources(
            Collections.singletonMap(TestEnum.ONE, "/test.jsp"));
        assertTrue(p.isWriteable(TestEnum.ONE.getClass(), null, null, null));
        assertEquals("/test.jsp", p.getResourcePath(TestEnum.ONE.getClass(), TestEnum.ONE));
    }
    
    private enum TestEnum {
        ONE,
        TWO
    }
}

==> apache-cxf-3.5.11-src.zip: apache-cxf-3.5.11-src/rt/frontend/jaxrs/src/test/java/org/apache/cxf/jaxrs/provider/RequestDispatcherProviderTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.jaxrs.provider;

import java.util.Collections;

import org.junit.Test;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;

public class RequestDispatcherProviderTest {

    @Test
    public void testIsWriteableEnum() {

        RequestDispatcherProvider p = new RequestDispatcherProvider();
        p.setClassResources(
            Collections.singletonMap(TestEnum.class.getName() + "." + TestEnum.ONE, "/test.jsp"));
        assertTrue(p.isWriteable(TestEnum.ONE.getClass(), null, null, null));
        assertEquals("/test.jsp", p.getResourcePath(TestEnum.ONE.getClass(), TestEnum.ONE));
    }

    @Test
    public void testIsWriteableEnum2() {

        RequestDispatcherProvider p = new RequestDispatcherProvider();
        p.setEnumResources(
            Collections.singletonMap(TestEnum.ONE, "/test.jsp"));
        assertTrue(p.isWriteable(TestEnum.ONE.getClass(), null, null, null));
        assertEquals("/test.jsp", p.getResourcePath(TestEnum.ONE.getClass(), TestEnum.ONE));
    }

    private enum TestEnum {
        ONE,
        TWO
    }
}
